#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Dec 10 15:07:10 2020

@author: samuel.niang@cern.ch
"""

from GBARpy.Main_window import MainWindow
# Uncomment for edit mode
from Main_window import MainWindow

print('  _|_|_|  _|_|_|      _|_|    _|_|_|  ', '\n',
      '_|        _|    _|  _|    _|  _|    _|', '\n',
      '_|  _|_|  _|_|_|    _|_|_|_|  _|_|_|  ', '\n',
      '_|    _|  _|    _|  _|    _|  _|    _|', '\n',
      '  _|_|_|  _|_|_|    _|    _|  _|    _|')

win = MainWindow()            
win.mainloop()
win.quit()
